@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007 Holger Macht <holger@homac.de>
+ * Copyright (C) 2007,2008 Holger Macht <holger@homac.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -27,10 +27,10 @@
 #include <string.h>
 #include <stdlib.h>
 
-#include <hildon/hildon-program.h>
-#include <hildon/hildon-vvolumebar.h>
-#include <hildon/hildon-seekbar.h>
-#include <hildon/hildon-banner.h>
+#include <hildon-widgets/hildon-program.h>
+#include <hildon-widgets/hildon-vvolumebar.h>
+#include <hildon-widgets/hildon-seekbar.h>
+#include <hildon-widgets/hildon-banner.h>
 
 #include "main.h"
 
@@ -104,7 +104,7 @@ static void label_set_text_as_time(int time, GtkWidget *label)
 		min_str = g_strdup_printf("0%d", minutes);
 	else
 		min_str = g_strdup_printf("%d", minutes);
-	
+
 	text = g_strdup_printf("%s:%s", min_str, sec_str);
 
 	gtk_label_set_text(GTK_LABEL(label), text);
@@ -162,7 +162,7 @@ static void player_update(int state)
 		gtk_widget_set_sensitive(GTK_WIDGET(ui.play_button), FALSE);
 		gtk_widget_set_sensitive(GTK_WIDGET(ui.stop_button), FALSE);
 		gtk_widget_set_sensitive(GTK_WIDGET(ui.tb.seekbar), FALSE);
-		
+
 	} else if (state == MPD_PLAYER_STOP) {
 		GtkWidget *play_image = gtk_image_new_from_pixbuf(ui.pixbufs.play_button);
 		gtk_button_set_image(GTK_BUTTON(ui.play_button), play_image);
@@ -230,7 +230,7 @@ static void volumebar_mute_toggled()
 		return;
 
 	muted = hildon_volumebar_get_mute(HILDON_VOLUMEBAR(ui.volumebar));
-	
+
 	if (muted) {
 		value = hildon_volumebar_get_level(HILDON_VOLUMEBAR(ui.volumebar));
 		mpd_status_set_volume(connection, 0);
@@ -284,13 +284,14 @@ static GtkWidget *playlist_create(void)
 						    "Icon",
 						    renderer,
 						    "stock-id", SONG_STOCK_ID, NULL);
-	
+
 	renderer = gtk_cell_renderer_text_new();
+
 	gtk_tree_view_insert_column_with_attributes(GTK_TREE_VIEW(ui.playlist),
-						    -1,
-						    "Song",
-						    renderer,
-						    "text", SONG_TITLE, NULL);
+						    -1, "Song", renderer,
+						    "text", SONG_TITLE,
+						    "weight", WEIGHT_INT,
+						    NULL);
 
 	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(ui.playlist), FALSE);
 	gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(ui.playlist), TRUE);
@@ -496,7 +497,7 @@ void player_mpd_state_changed(MpdObj *mi, ChangedStatusType what, void *userdata
 
 	if (what & MPD_CST_SONGID)
 		player_song_changed();
-	
+
 	if (what & MPD_CST_STATE)
 		player_update(mpd_player_get_state(connection));
 
@@ -516,19 +517,19 @@ static GtkWidget *toolbar_create()
 	GtkWidget	*image		= NULL;
 	GtkWidget	*toolbar	= NULL;
 	GtkToolItem	*item		= NULL;
-	
+
 	toolbar = gtk_toolbar_new();
-	
+
 	image = gtk_image_new();
 	gtk_image_set_from_stock(GTK_IMAGE(image), "media-unmuted", GTK_ICON_SIZE_BUTTON);
 	item = gtk_tool_button_new(GTK_WIDGET(image), "Volume");
 	g_signal_connect(G_OBJECT(item), "clicked", G_CALLBACK(volumebar_show), NULL);
 	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), item, -1);
-	
+
 	item = gtk_tool_button_new_from_stock(GTK_STOCK_PREFERENCES);
 	g_signal_connect(G_OBJECT(item), "clicked", G_CALLBACK(create_preferences_window), NULL);
 	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), item, -1);
-	
+
 	image = gtk_image_new();
 	gtk_image_set_from_stock(GTK_IMAGE(image), "media-playlist", GTK_ICON_SIZE_BUTTON);
 	item = gtk_tool_button_new(GTK_WIDGET(image), "Playlist");
@@ -597,7 +598,7 @@ void player_create()
 	hildon_window_add_toolbar(ui.main_window, GTK_TOOLBAR(toolbar_create()));
 
 	mmpc_attach(HILDON_WINDOW(ui.main_window), G_CALLBACK(gtk_main_quit), NULL);
-	
+
 	g_signal_connect(G_OBJECT(ui.main_window), "delete_event",
 			 G_CALLBACK(gtk_main_quit), NULL);
 
@@ -618,13 +619,14 @@ void player_create()
 
 	/* vbox_left */
 	ui.vbox_left = gtk_vbox_new(FALSE, 5);
-	gtk_widget_set_size_request(GTK_WIDGET(ui.vbox_left), 150, 100);
+	/* if we want bigger buttons, change this
+	gtk_widget_set_size_request(GTK_WIDGET(ui.vbox_left), 150, 100);*/
 
-	ui.pixbufs.play_button = pixbuf_get("play_button.png");
-	pixbuf_stop_button = pixbuf_get("stop_button.png");
-	ui.pixbufs.pause_button = pixbuf_get("pause_button.png");
-	pixbuf_forward_button = pixbuf_get("forward_button.png");
-	pixbuf_backward_button = pixbuf_get("backward_button.png");
+	ui.pixbufs.play_button = pixbuf_get("media-playback-start.png");
+	pixbuf_stop_button = pixbuf_get("media-playback-stop.png");
+	ui.pixbufs.pause_button = pixbuf_get("media-playback-pause.png");
+	pixbuf_forward_button = pixbuf_get("media-skip-forward.png");
+	pixbuf_backward_button = pixbuf_get("media-skip-backward.png");
 
 	ui.play_button = gtk_button_new();
 	gtk_button_set_image(GTK_BUTTON(ui.play_button),
@@ -655,7 +657,8 @@ void player_create()
 	/* volumebar */
 	ui.volumebar = HILDON_VOLUMEBAR(hildon_vvolumebar_new());
 	gtk_widget_get_child_requisition(ui.vbox_left, &requisition);
-	gtk_widget_set_size_request(GTK_WIDGET(ui.volumebar), requisition.width, requisition.height);
+	/* do we want the buttons and the volumebar on the left having the same size?
+	gtk_widget_set_size_request(GTK_WIDGET(ui.volumebar), requisition.width, requisition.height);*/
 	g_signal_connect(G_OBJECT(ui.volumebar), "level_changed",
 			 G_CALLBACK(volumebar_clicked), NULL);
 	g_signal_connect(G_OBJECT(ui.volumebar), "mute_toggled",
